.. image:: https://github.com/gelles-brandeis/tapqir/raw/latest/docs/source/_static/logo.png
   :target: https://tapqir.readthedocs.io/
   :alt: Tapqir logo

*Bayesian analysis of co-localization single-molecule microscopy image data.*

---------

.. |ci| image:: https://github.com/gelles-brandeis/tapqir/workflows/build/badge.svg
  :target: https://github.com/gelles-brandeis/tapqir/actions

.. |docs| image:: https://readthedocs.org/projects/tapqir/badge/?version=latest
    :alt: Documentation Status
    :scale: 100%
    :target: https://tapqir.readthedocs.io/
    
.. |pypi| image:: https://badge.fury.io/py/tapqir.svg
    :alt: PyPI version
    :target: https://pypi.org/project/tapqir/

.. |black| image:: https://img.shields.io/badge/code%20style-black-000000.svg
  :target: https://github.com/ambv/black
  
.. |DOI| image:: https://img.shields.io/badge/DOI-10.7554%2FeLife.73860-blue
   :target: https://doi.org/10.7554/eLife.73860
   :alt: DOI

|DOI| |ci| |docs| |pypi| |black|

`Publication <https://doi.org/10.7554/eLife.73860>`_ |
`Documentation & Tutorials <https://tapqir.readthedocs.io/>`_ |
`Discussions/Q&As <https://github.com/gelles-brandeis/tapqir/discussions/>`_

Publication
-----------

Tapqir and the *cosmos* model are described in Ordabayev et al., "Bayesian machine learning analysis of single-molecule fluorescence colocalization images" eLife 2022;11:e73860 `doi: 10.7554/eLife.73860 <https://doi.org/10.7554/eLife.73860>`_

Documentation & Tutorials
-------------------------

Please visit our `website <https://tapqir.readthedocs.io/>`_ for documentation, tutorials, and general information.

Announcements
-------------

To get notified about new releases sign in to Github, go to top right corner of this page and click on Watch -> Custom -> Releases.

Discussions/Q&As
----------------

Please post questions about the software on our `forum <https://github.com/gelles-brandeis/tapqir/discussions>`_. We will try to respond promptly.

Changelog
---------

To see the entire list of releases and changelogs go to `releases <https://github.com/gelles-brandeis/tapqir/releases>`_.
